var util = require('util'),
    _ = require('underscore'),
    AbstractApi = require('abstract-api');

function GoPostal(base_url, key) {
  AbstractApi.call(this, base_url);
  this.key = key;
}

util.inherits(GoPostal, AbstractApi);

GoPostal.prototype.setRequestOptions = function(options, httpMethod, method, params) {
  options.method = httpMethod;
  options.uri.pathname += method;
  options.headers = _.extend(options.headers || {}, {
    Accept: 'application/json',
    'Content-Type': 'application/json',
    'Authorization': 'Basic ' + new Buffer(this.key).toString('base64')
  });
  switch (httpMethod) {
    case 'GET':
      _.extend(options.uri.query, params);
      break;
    case 'POST':
      options.json = params;
      break;
    default:
      throw new Error('Only GET and POST are currently supported');
  }
  return options;
};

GoPostal.prototype.getUsers = function(callback) {
  this.get('users', callback);
};

GoPostal.prototype.getUser = function(id, callback) {
  this.get('user/' + id, callback);
};

GoPostal.prototype.createUser = function(username, name, callback) {
  this.post('user', {username: username, name: name}, callback);
};

GoPostal.prototype.addAccount = function(user, type, config, callback) {
  this.post('user/' + user + '/accounts/' + type + '/add', config, callback);
};

module.exports = GoPostal;